@@ -46,6 +46,18 @@ function() {
       abline(as.numeric(tclvalue(Env$l.var$add.param2)),as.numeric(tclvalue(Env$l.var$add.param1)),
 	  lty=type.trait(type=tclvalue(Env$l.var$add.trait)),lwd=as.numeric(tclvalue(Env$l.var$add.epaisseur1)),
 	  col=tclvalue(Env$l.var$add.col1),untf=ifelse(graphe.log()=="",FALSE,TRUE))
+	if (Env$l.code$save==TRUE) {
+	  sink(file=file.path(Env$l.code$folder,paste(paste("GrapheR",paste(strsplit(as.character(Sys.Date()),split="-")[[1]],collapse="."),
+	    sep="-"),".R",sep=""),fsep=.Platform$file.sep),append=TRUE)
+	  cat("# Added: straight line\n\n")
+	  texte<-paste("abline(",tclvalue(Env$l.var$add.param2),", ",tclvalue(Env$l.var$add.param1),sep="")
+	  if (tclvalue(Env$l.var$add.col1)!="black" & tclvalue(Env$l.var$add.col1)!="#000000") {texte<-paste(texte,", col=\"",tclvalue(Env$l.var$add.col1),"\"",sep="")}
+	  texte<-paste(texte,", lty=",type.trait(type=tclvalue(Env$l.var$add.trait)),sep="")
+	  texte<-paste(texte,", lwd=",tclvalue(Env$l.var$add.epaisseur1),sep="")
+	  texte<-paste(texte,", untf=",ifelse(graphe.log()=="","FALSE","TRUE"),")\n\n",sep="")
+	  cat(texte)
+	  sink(NULL)
+	}
     } else {
 	msg(text=Env$voc[163,1],type="error")
     }
